@@ -1,11 +1,12 @@
 package POOF::Exception;
 
-use base qw(POOF);
+use 5.007;
 use strict;
 use warnings;
+use base qw(POOF);
 use Carp qw(confess croak);
 
-use Data::Dumper;
+our $VERSION = '1.0';
 
 #-------------------------------------------------------------------------------
 # Properties: Core
@@ -54,5 +55,30 @@ sub _init
 
 
 1;
+__END__
 
-__END__
\ No newline at end of file
+=head1 NAME
+
+POOF::Exception - Utility class used by POOF.
+
+=head1 SYNOPSIS
+
+It is not meant to be used directly.
+  
+=head1 SEE ALSO
+
+POOF man page.
+
+=head1 AUTHOR
+
+Benny Millares <bmillares@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2007 by Benny Millares
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.8 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
