@@ -1,16 +1,15 @@
 package POOF::Properties;
 
-use 5.006;
+use 5.007;
 use strict;
 use warnings;
 
-use Data::Dumper qw(Dumper);
 use Carp qw(croak confess);
 use Class::ISA;
 
 use POOF::DataType;
 
-our $VERSION = '0.01';
+our $VERSION = '1.0';
 
 use constant ACCESSLEVEL =>
 {
@@ -639,3 +638,29 @@ sub _initializeHash
 
 1;
 __END__
+
+=head1 NAME
+
+POOF::Properties - Utility class used by POOF.
+
+=head1 SYNOPSIS
+
+It is not meant to be used directly.
+  
+=head1 SEE ALSO
+
+POOF man page.
+
+=head1 AUTHOR
+
+Benny Millares <bmillares@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2007 by Benny Millares
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.8 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
